==> dda-httpd-crate-0.2.4-20171128.124923-1.jar: dda/pallet/dda_httpd_crate/domain/schema.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.dda-httpd-crate.domain.schema
  (:require
    [schema.core :as s]))

(def VhostConfig
  {(s/optional-key :google-id) s/Str
   (s/optional-key :settings)
   (hash-set (s/enum :test
                     :without-maintainance
                     :with-php))})

(def SingleStaticConfig
  (merge
    {:domain-name s/Str
     (s/optional-key :alias) [{:url s/Str :path s/Str}]}
    VhostConfig))

;e.g. (s/validate SingleStaticConfig
;{:domain-name "aef" :alias [{:url "url" :path "path"}] :settings (hash-set :test :with-php)}

(def MultiStaticConfig
  {s/Keyword VhostConfig})

(def JkConfig
  (merge
    VhostConfig
    {:domain-name s/Str
     (s/optional-key :settings)
     (hash-set (s/enum :test
                       :without-maintainance))}))

==> dda-httpd-crate-0.2.4-20171206.230104-2.jar: dda/pallet/dda_httpd_crate/domain/schema.clj <==
; Licensed to the Apache Software Foundation (ASF) under one
; or more contributor license agreements. See the NOTICE file
; distributed with this work for additional information
; regarding copyright ownership. The ASF licenses this file
; to you under the Apache License, Version 2.0 (the
; "License"); you may not use this file except in compliance
; with the License. You may obtain a copy of the License at
;
; http://www.apache.org/licenses/LICENSE-2.0
;
; Unless required by applicable law or agreed to in writing, software
; distributed under the License is distributed on an "AS IS" BASIS,
; WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
; See the License for the specific language governing permissions and
; limitations under the License.
(ns dda.pallet.dda-httpd-crate.domain.schema
  (:require
    [schema.core :as s]))

(def VhostConfig
  {(s/optional-key :google-id) s/Str
   (s/optional-key :settings)
   (hash-set (s/enum :test
                     :without-maintainance
                     :with-php))})

(def SingleStaticConfig
  (merge
    {:domain-name s/Str
     (s/optional-key :alias) [{:url s/Str :path s/Str}]
     (s/optional-key :alias-match) [{:regex s/Str :path s/Str}]}
    VhostConfig))

;e.g. (s/validate SingleStaticConfig
;{:domain-name "aef" :alias [{:url "url" :path "path"}] :settings (hash-set :test :with-php)}

(def MultiStaticConfig
  {s/Keyword VhostConfig})

(def JkConfig
  (merge
    VhostConfig
    {:domain-name s/Str
     (s/optional-key :settings)
     (hash-set (s/enum :test
                       :without-maintainance))}))
